Class: KlaviyoBeta::CatalogVariantCreateQueryDataAttributes

Inherits:
Object
  • Object
show all
Defined in:
lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CatalogVariantCreateQueryDataAttributes

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 125

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoBeta::CatalogVariantCreateQueryDataAttributes` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoBeta::CatalogVariantCreateQueryDataAttributes`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'external_id')
    self.external_id = attributes[:'external_id']
  end

  if attributes.key?(:'catalog_type')
    self.catalog_type = attributes[:'catalog_type']
  end

  if attributes.key?(:'integration_type')
    self.integration_type = attributes[:'integration_type']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'sku')
    self.sku = attributes[:'sku']
  end

  if attributes.key?(:'inventory_policy')
    self.inventory_policy = attributes[:'inventory_policy']
  end

  if attributes.key?(:'inventory_quantity')
    self.inventory_quantity = attributes[:'inventory_quantity']
  end

  if attributes.key?(:'price')
    self.price = attributes[:'price']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'image_full_url')
    self.image_full_url = attributes[:'image_full_url']
  end

  if attributes.key?(:'image_thumbnail_url')
    self.image_thumbnail_url = attributes[:'image_thumbnail_url']
  end

  if attributes.key?(:'images')
    if (value = attributes[:'images']).is_a?(Array)
      self.images = value
    end
  end

  if attributes.key?(:'custom_metadata')
    self. = attributes[:'custom_metadata']
  end

  if attributes.key?(:'published')
    self.published = attributes[:'published']
  end
end

Instance Attribute Details

#catalog_typeObject

Returns the value of attribute catalog_type.



20
21
22
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 20

def catalog_type
  @catalog_type
end

#custom_metadataObject

Returns the value of attribute custom_metadata.



44
45
46
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 44

def 
  @custom_metadata
end

#descriptionObject

Returns the value of attribute description.



26
27
28
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 26

def description
  @description
end

#external_idObject

Returns the value of attribute external_id.



18
19
20
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 18

def external_id
  @external_id
end

#image_full_urlObject

Returns the value of attribute image_full_url.



38
39
40
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 38

def image_full_url
  @image_full_url
end

#image_thumbnail_urlObject

Returns the value of attribute image_thumbnail_url.



40
41
42
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 40

def image_thumbnail_url
  @image_thumbnail_url
end

#imagesObject

Returns the value of attribute images.



42
43
44
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 42

def images
  @images
end

#integration_typeObject

Returns the value of attribute integration_type.



22
23
24
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 22

def integration_type
  @integration_type
end

#inventory_policyObject

Returns the value of attribute inventory_policy.



30
31
32
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 30

def inventory_policy
  @inventory_policy
end

#inventory_quantityObject

Returns the value of attribute inventory_quantity.



32
33
34
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 32

def inventory_quantity
  @inventory_quantity
end

#priceObject

Returns the value of attribute price.



34
35
36
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 34

def price
  @price
end

#publishedObject

Returns the value of attribute published.



46
47
48
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 46

def published
  @published
end

#skuObject

Returns the value of attribute sku.



28
29
30
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 28

def sku
  @sku
end

#titleObject

Returns the value of attribute title.



24
25
26
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 24

def title
  @title
end

#urlObject

Returns the value of attribute url.



36
37
38
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 36

def url
  @url
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 92

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 71

def self.attribute_map
  {
    :'external_id' => :'external_id',
    :'catalog_type' => :'catalog_type',
    :'integration_type' => :'integration_type',
    :'title' => :'title',
    :'description' => :'description',
    :'sku' => :'sku',
    :'inventory_policy' => :'inventory_policy',
    :'inventory_quantity' => :'inventory_quantity',
    :'price' => :'price',
    :'url' => :'url',
    :'image_full_url' => :'image_full_url',
    :'image_thumbnail_url' => :'image_thumbnail_url',
    :'images' => :'images',
    :'custom_metadata' => :'custom_metadata',
    :'published' => :'published'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



315
316
317
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 315

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



118
119
120
121
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 118

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 97

def self.openapi_types
  {
    :'external_id' => :'String',
    :'catalog_type' => :'String',
    :'integration_type' => :'String',
    :'title' => :'String',
    :'description' => :'String',
    :'sku' => :'String',
    :'inventory_policy' => :'Integer',
    :'inventory_quantity' => :'Float',
    :'price' => :'Float',
    :'url' => :'String',
    :'image_full_url' => :'String',
    :'image_thumbnail_url' => :'String',
    :'images' => :'Array<String>',
    :'custom_metadata' => :'Object',
    :'published' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 280

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      external_id == o.external_id &&
      catalog_type == o.catalog_type &&
      integration_type == o.integration_type &&
      title == o.title &&
      description == o.description &&
      sku == o.sku &&
      inventory_policy == o.inventory_policy &&
      inventory_quantity == o.inventory_quantity &&
      price == o.price &&
      url == o.url &&
      image_full_url == o.image_full_url &&
      image_thumbnail_url == o.image_thumbnail_url &&
      images == o.images &&
       == o. &&
      published == o.published
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 346

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KlaviyoBeta.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



417
418
419
420
421
422
423
424
425
426
427
428
429
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 417

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 322

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


302
303
304
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 302

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



308
309
310
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 308

def hash
  [external_id, catalog_type, integration_type, title, description, sku, inventory_policy, inventory_quantity, price, url, image_full_url, image_thumbnail_url, images, , published].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 203

def list_invalid_properties
  invalid_properties = Array.new
  if @external_id.nil?
    invalid_properties.push('invalid value for "external_id", external_id cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @sku.nil?
    invalid_properties.push('invalid value for "sku", sku cannot be nil.')
  end

  if @inventory_policy.nil?
    invalid_properties.push('invalid value for "inventory_policy", inventory_policy cannot be nil.')
  end

  if @inventory_quantity.nil?
    invalid_properties.push('invalid value for "inventory_quantity", inventory_quantity cannot be nil.')
  end

  if @price.nil?
    invalid_properties.push('invalid value for "price", price cannot be nil.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



393
394
395
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 393

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



399
400
401
402
403
404
405
406
407
408
409
410
411
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 399

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



387
388
389
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 387

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/klaviyo_sdk_beta/models/catalog_variant_create_query_data_attributes.rb', line 242

def valid?
  return false if @external_id.nil?
  integration_type_validator = EnumAttributeValidator.new('String', ["$custom"])
  return false unless integration_type_validator.valid?(@integration_type)
  return false if @title.nil?
  return false if @description.nil?
  return false if @sku.nil?
  return false if @inventory_policy.nil?
  inventory_policy_validator = EnumAttributeValidator.new('Integer', [0, 1, 2])
  return false unless inventory_policy_validator.valid?(@inventory_policy)
  return false if @inventory_quantity.nil?
  return false if @price.nil?
  return false if @url.nil?
  true
end