Class: KlaviyoBeta::ListsApi
- Inherits:
-
Object
- Object
- KlaviyoBeta::ListsApi
- Defined in:
- lib/klaviyo_sdk_beta/api/lists_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_list(list_create_query, opts = {}) ⇒ Hash<String, Object>
Create List Create a list
*Rate limits*:
Burst: `10/s`
Steady: `150/m`. -
#create_list_relationships(id, related_resource, list_members_add_query, opts = {}) ⇒ nil
Add Profile to List Add profiles to a list.
-
#create_list_relationships_with_http_info(id, related_resource, list_members_add_query, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Add Profile to List Add profiles to a list.
-
#create_list_with_http_info(list_create_query, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Create List Create a list<br><br>*Rate limits*:<br>Burst: `10/s`<br>Steady: `150/m`.
-
#delete_list(id, opts = {}) ⇒ nil
Delete List Delete a list
*Rate limits*:
Burst: `10/s`
Steady: `150/m`. -
#delete_list_relationships(id, related_resource, list_members_delete_query, opts = {}) ⇒ nil
Remove Profile from List Removes profiles from a list.
-
#delete_list_relationships_with_http_info(id, related_resource, list_members_delete_query, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove Profile from List Removes profiles from a list.
-
#delete_list_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete List Delete a list<br><br>*Rate limits*:<br>Burst: `10/s`<br>Steady: `150/m`.
-
#get_list(id, opts = {}) ⇒ Hash<String, Object>
Get List Returns a specific list in an account based on a required LIST_ID.
*Rate limits*:
Burst: `10/s`
Steady: `150/m`. -
#get_list_profiles(list_id, opts = {}) ⇒ Hash<String, Object>
Get List Profiles Returns a list of all profiles inside a given list, that can optionally be filtered by email and/or phone number.
-
#get_list_profiles_with_http_info(list_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Get List Profiles Returns a list of all profiles inside a given list, that can optionally be filtered by email and/or phone number.
-
#get_list_relationships(id, related_resource, opts = {}) ⇒ Hash<String, Object>
Get List Profile Relationships Returns a list of profile membership relationships for a given list.
-
#get_list_relationships_with_http_info(id, related_resource, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Get List Profile Relationships Returns a list of profile membership relationships for a given list.
-
#get_list_with_http_info(id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Get List Returns a specific list in an account based on a required LIST_ID.<br><br>*Rate limits*:<br>Burst: `10/s`<br>Steady: `150/m`.
-
#get_lists(opts = {}) ⇒ Hash<String, Object>
Get Lists Returns some or all lists in an account based on [optional] filters
*Rate limits*:
Burst: `10/s`
Steady: `150/m`. -
#get_lists_with_http_info(opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Get Lists Returns some or all lists in an account based on [optional] filters<br><br>*Rate limits*:<br>Burst: `10/s`<br>Steady: `150/m`.
-
#initialize(api_client = ApiClient.default) ⇒ ListsApi
constructor
A new instance of ListsApi.
-
#update_list(id, list_partial_update_query, opts = {}) ⇒ Hash<String, Object>
Update List Update list name or other attributes.
*Rate limits*:
Burst: `10/s`
Steady: `150/m`. -
#update_list_with_http_info(id, list_partial_update_query, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Update List Update list name or other attributes.<br><br>*Rate limits*:<br>Burst: `10/s`<br>Steady: `150/m`.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_list(list_create_query, opts = {}) ⇒ Hash<String, Object>
Create List Create a list
*Rate limits*:
Burst: `10/s`
Steady: `150/m`
27 28 29 30 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 27 def create_list(list_create_query, opts = {}) data, _status_code, _headers = create_list_with_http_info(list_create_query, opts) data end |
#create_list_relationships(id, related_resource, list_members_add_query, opts = {}) ⇒ nil
Add Profile to List Add profiles to a list
99 100 101 102 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 99 def create_list_relationships(id, , list_members_add_query, opts = {}) create_list_relationships_with_http_info(id, , list_members_add_query, opts) nil end |
#create_list_relationships_with_http_info(id, related_resource, list_members_add_query, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Add Profile to List Add profiles to a list
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 111 def create_list_relationships_with_http_info(id, , list_members_add_query, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ListsApi.create_list_relationships ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ListsApi.create_list_relationships" end # verify the required parameter 'related_resource' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'related_resource' when calling ListsApi.create_list_relationships" end # verify enum value allowable_values = ["profiles"] if @api_client.config.client_side_validation && !allowable_values.include?() fail ArgumentError, "invalid value for \"related_resource\", must be one of #{allowable_values}" end # verify the required parameter 'list_members_add_query' is set if @api_client.config.client_side_validation && list_members_add_query.nil? fail ArgumentError, "Missing the required parameter 'list_members_add_query' when calling ListsApi.create_list_relationships" end # resource path local_var_path = '/api/lists/{id}/relationships/{related_resource}/'.sub('{' + 'id' + '}', CGI.escape(id.to_s)).sub('{' + 'related_resource' + '}', CGI.escape(.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # klaviyo api revision header_params['revision'] = ENV['API_REVISION'] || "2022-09-07.pre" # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(list_members_add_query) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['Klaviyo-API-Key'] = opts.merge( :operation => :"ListsApi.create_list_relationships", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ListsApi#create_list_relationships\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_list_with_http_info(list_create_query, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Create List Create a list<br><br>*Rate limits*:<br>Burst: `10/s`<br>Steady: `150/m`
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 37 def create_list_with_http_info(list_create_query, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ListsApi.create_list ...' end # verify the required parameter 'list_create_query' is set if @api_client.config.client_side_validation && list_create_query.nil? fail ArgumentError, "Missing the required parameter 'list_create_query' when calling ListsApi.create_list" end # resource path local_var_path = '/api/lists/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # klaviyo api revision header_params['revision'] = ENV['API_REVISION'] || "2022-09-07.pre" # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(list_create_query) # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['Klaviyo-API-Key'] = opts.merge( :operation => :"ListsApi.create_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ListsApi#create_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_list(id, opts = {}) ⇒ nil
Delete List Delete a list
*Rate limits*:
Burst: `10/s`
Steady: `150/m`
184 185 186 187 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 184 def delete_list(id, opts = {}) delete_list_with_http_info(id, opts) nil end |
#delete_list_relationships(id, related_resource, list_members_delete_query, opts = {}) ⇒ nil
Remove Profile from List Removes profiles from a list
251 252 253 254 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 251 def delete_list_relationships(id, , list_members_delete_query, opts = {}) delete_list_relationships_with_http_info(id, , list_members_delete_query, opts) nil end |
#delete_list_relationships_with_http_info(id, related_resource, list_members_delete_query, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove Profile from List Removes profiles from a list
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 263 def delete_list_relationships_with_http_info(id, , list_members_delete_query, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ListsApi.delete_list_relationships ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ListsApi.delete_list_relationships" end # verify the required parameter 'related_resource' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'related_resource' when calling ListsApi.delete_list_relationships" end # verify enum value allowable_values = ["profiles"] if @api_client.config.client_side_validation && !allowable_values.include?() fail ArgumentError, "invalid value for \"related_resource\", must be one of #{allowable_values}" end # verify the required parameter 'list_members_delete_query' is set if @api_client.config.client_side_validation && list_members_delete_query.nil? fail ArgumentError, "Missing the required parameter 'list_members_delete_query' when calling ListsApi.delete_list_relationships" end # resource path local_var_path = '/api/lists/{id}/relationships/{related_resource}/'.sub('{' + 'id' + '}', CGI.escape(id.to_s)).sub('{' + 'related_resource' + '}', CGI.escape(.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # klaviyo api revision header_params['revision'] = ENV['API_REVISION'] || "2022-09-07.pre" # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(list_members_delete_query) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['Klaviyo-API-Key'] = opts.merge( :operation => :"ListsApi.delete_list_relationships", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ListsApi#delete_list_relationships\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_list_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete List Delete a list<br><br>*Rate limits*:<br>Burst: `10/s`<br>Steady: `150/m`
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 194 def delete_list_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ListsApi.delete_list ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ListsApi.delete_list" end # resource path local_var_path = '/api/lists/{id}/'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # klaviyo api revision header_params['revision'] = ENV['API_REVISION'] || "2022-09-07.pre" # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['Klaviyo-API-Key'] = opts.merge( :operation => :"ListsApi.delete_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ListsApi#delete_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_list(id, opts = {}) ⇒ Hash<String, Object>
Get List Returns a specific list in an account based on a required LIST_ID.
*Rate limits*:
Burst: `10/s`
Steady: `150/m`
337 338 339 340 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 337 def get_list(id, opts = {}) data, _status_code, _headers = get_list_with_http_info(id, opts) data end |
#get_list_profiles(list_id, opts = {}) ⇒ Hash<String, Object>
Get List Profiles Returns a list of all profiles inside a given list, that can optionally be filtered by email and/or phone number.
411 412 413 414 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 411 def get_list_profiles(list_id, opts = {}) data, _status_code, _headers = get_list_profiles_with_http_info(list_id, opts) data end |
#get_list_profiles_with_http_info(list_id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Get List Profiles Returns a list of all profiles inside a given list, that can optionally be filtered by email and/or phone number.
424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 424 def get_list_profiles_with_http_info(list_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ListsApi.get_list_profiles ...' end # verify the required parameter 'list_id' is set if @api_client.config.client_side_validation && list_id.nil? fail ArgumentError, "Missing the required parameter 'list_id' when calling ListsApi.get_list_profiles" end allowable_values = ["email", "phone_number", "external_id", "anonymous_id", "first_name", "last_name", "organization", "title", "image", "created", "updated", "last_event_date", "location", "location.address1", "location.address2", "location.city", "location.country", "location.latitude", "location.longitude", "location.region", "location.zip", "location.timezone", "properties"] if @api_client.config.client_side_validation && opts[:'fields_profile'] && !opts[:'fields_profile'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"fields_profile\", must include one of #{allowable_values}" end # resource path local_var_path = '/api/lists/{list_id}/profiles/'.sub('{' + 'list_id' + '}', CGI.escape(list_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'fields[profile]'] = @api_client.build_collection_param(opts[:'fields_profile'], :csv) if !opts[:'fields_profile'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'page[cursor]'] = opts[:'page_cursor'] if !opts[:'page_cursor'].nil? # header parameters header_params = opts[:header_params] || {} # klaviyo api revision header_params['revision'] = ENV['API_REVISION'] || "2022-09-07.pre" # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['Klaviyo-API-Key'] = opts.merge( :operation => :"ListsApi.get_list_profiles", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ListsApi#get_list_profiles\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_list_relationships(id, related_resource, opts = {}) ⇒ Hash<String, Object>
Get List Profile Relationships Returns a list of profile membership relationships for a given list
488 489 490 491 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 488 def get_list_relationships(id, , opts = {}) data, _status_code, _headers = get_list_relationships_with_http_info(id, , opts) data end |
#get_list_relationships_with_http_info(id, related_resource, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Get List Profile Relationships Returns a list of profile membership relationships for a given list
500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 500 def get_list_relationships_with_http_info(id, , opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ListsApi.get_list_relationships ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ListsApi.get_list_relationships" end # verify the required parameter 'related_resource' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'related_resource' when calling ListsApi.get_list_relationships" end # verify enum value allowable_values = ["profiles"] if @api_client.config.client_side_validation && !allowable_values.include?() fail ArgumentError, "invalid value for \"related_resource\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/lists/{id}/relationships/{related_resource}/'.sub('{' + 'id' + '}', CGI.escape(id.to_s)).sub('{' + 'related_resource' + '}', CGI.escape(.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page[cursor]'] = opts[:'page_cursor'] if !opts[:'page_cursor'].nil? # header parameters header_params = opts[:header_params] || {} # klaviyo api revision header_params['revision'] = ENV['API_REVISION'] || "2022-09-07.pre" # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['Klaviyo-API-Key'] = opts.merge( :operation => :"ListsApi.get_list_relationships", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ListsApi#get_list_relationships\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_list_with_http_info(id, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Get List Returns a specific list in an account based on a required LIST_ID.<br><br>*Rate limits*:<br>Burst: `10/s`<br>Steady: `150/m`
348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 348 def get_list_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ListsApi.get_list ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ListsApi.get_list" end allowable_values = ["name", "created", "updated"] if @api_client.config.client_side_validation && opts[:'fields_list'] && !opts[:'fields_list'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"fields_list\", must include one of #{allowable_values}" end # resource path local_var_path = '/api/lists/{id}/'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'fields[list]'] = @api_client.build_collection_param(opts[:'fields_list'], :csv) if !opts[:'fields_list'].nil? # header parameters header_params = opts[:header_params] || {} # klaviyo api revision header_params['revision'] = ENV['API_REVISION'] || "2022-09-07.pre" # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['Klaviyo-API-Key'] = opts.merge( :operation => :"ListsApi.get_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ListsApi#get_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_lists(opts = {}) ⇒ Hash<String, Object>
Get Lists Returns some or all lists in an account based on [optional] filters
*Rate limits*:
Burst: `10/s`
Steady: `150/m`
567 568 569 570 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 567 def get_lists(opts = {}) data, _status_code, _headers = get_lists_with_http_info(opts) data end |
#get_lists_with_http_info(opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Get Lists Returns some or all lists in an account based on [optional] filters<br><br>*Rate limits*:<br>Burst: `10/s`<br>Steady: `150/m`
579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 579 def get_lists_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ListsApi.get_lists ...' end allowable_values = ["name", "created", "updated"] if @api_client.config.client_side_validation && opts[:'fields_list'] && !opts[:'fields_list'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"fields_list\", must include one of #{allowable_values}" end # resource path local_var_path = '/api/lists/' # query parameters query_params = opts[:query_params] || {} query_params[:'fields[list]'] = @api_client.build_collection_param(opts[:'fields_list'], :csv) if !opts[:'fields_list'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'page[cursor]'] = opts[:'page_cursor'] if !opts[:'page_cursor'].nil? # header parameters header_params = opts[:header_params] || {} # klaviyo api revision header_params['revision'] = ENV['API_REVISION'] || "2022-09-07.pre" # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['Klaviyo-API-Key'] = opts.merge( :operation => :"ListsApi.get_lists", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ListsApi#get_lists\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_list(id, list_partial_update_query, opts = {}) ⇒ Hash<String, Object>
Update List Update list name or other attributes.
*Rate limits*:
Burst: `10/s`
Steady: `150/m`
638 639 640 641 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 638 def update_list(id, list_partial_update_query, opts = {}) data, _status_code, _headers = update_list_with_http_info(id, list_partial_update_query, opts) data end |
#update_list_with_http_info(id, list_partial_update_query, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Update List Update list name or other attributes.<br><br>*Rate limits*:<br>Burst: `10/s`<br>Steady: `150/m`
649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 |
# File 'lib/klaviyo_sdk_beta/api/lists_api.rb', line 649 def update_list_with_http_info(id, list_partial_update_query, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ListsApi.update_list ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ListsApi.update_list" end # verify the required parameter 'list_partial_update_query' is set if @api_client.config.client_side_validation && list_partial_update_query.nil? fail ArgumentError, "Missing the required parameter 'list_partial_update_query' when calling ListsApi.update_list" end # resource path local_var_path = '/api/lists/{id}/'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # klaviyo api revision header_params['revision'] = ENV['API_REVISION'] || "2022-09-07.pre" # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(list_partial_update_query) # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['Klaviyo-API-Key'] = opts.merge( :operation => :"ListsApi.update_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ListsApi#update_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |